@@ -1,7 +1,6 @@
-context("Sample TEF")
 test_that("Sample TEF", {
   set.seed(1234)
-  tef <- sample_tef(params = list(10, 1, 10, 100))
+  tef <- sample_tef(params = list(n=10, 1, 10, 100))
   expect_is(tef, "list")
   # ensure that the list has the required elements
   expect_equal(names(tef), c("type", "samples", "details"))
@@ -17,7 +16,7 @@ test_that("Sample TEF", {
 context("Sample DIFF")
 test_that("Sample DIFF", {
   set.seed(1234)
-  dat <- sample_diff(params = list(10, 50, 70, 75, 3))
+  dat <- sample_diff(params = list(n=10, 50, 70, 75, 3))
   expect_is(dat, "list")
   # ensure that the list has the required elements
   expect_equal(names(dat), c("type", "samples", "details"))
@@ -31,14 +30,14 @@ test_that("Sample DIFF", {
                         71.4683219144408), digits = 4))
 })
 test_that("Multi control diff works", {
-  diff_estimates <- data_frame(l = c(1, 2), ml = c(10, 15), h = c(20, 100),
+  diff_estimates <- data.frame(l = c(1, 2), ml = c(10, 15), h = c(20, 100),
                                conf = c(1, 3))
 })
 
 context("Sample TC")
 test_that("Sample TC", {
   set.seed(1234)
-  tc <- sample_tc(params = list(10, 50, 75, 100, 4))
+  tc <- sample_tc(params = list(n=10, 50, 75, 100, 4))
   expect_is(tc, "list")
   # ensure that the list has the required elements
   expect_equal(names(tc), c("type", "samples", "details"))
@@ -52,10 +51,18 @@ test_that("Sample TC", {
                         64.9764652390671), digits = 4))
 })
 
+context("Select Loss Opportunities")
+test_that("Mean Difficulty Exceedance works when there are zero losses", {
+  threat_strengths <- c(0.2, 0.3, 0.4)
+  diff_strengths   <- c(0.3, 0.4, 0.5)
+  dat <- select_loss_opportunities(threat_strengths, diff_strengths)
+  expect_equal(dat$details$mean_diff_exceedance, 0.1)
+})
+
 context("Sample VULN")
 test_that("Sample VULN works with binom", {
   set.seed(1234)
-  dat <- sample_vuln(params = list(10, 1, .5))
+  dat <- sample_vuln(params = list(n=10, 1, .5))
   expect_is(dat, "list")
   # ensure that the list has the required elements
   expect_equal(names(dat), c("type", "samples", "details"))
@@ -66,9 +73,9 @@ test_that("Sample VULN works with binom", {
 })
 test_that("Sample VULN works with TC and DIFF", {
   set.seed(1234)
-  tc <- sample_tc(params = list(10, 50, 70, 85, 2))$samples
-  diff <- sample_diff(params = list(10, 50, 70, 85, 2))$samples
-  dat <- sample_vuln(func = select_loss_opportunities, params = list(tc = tc, diff = diff))
+  tc <- sample_tc(params = list(n=10, 50, 70, 85, 2))$samples
+  diff <- sample_diff(params = list(n=10, 50, 70, 85, 2))$samples
+  dat <- sample_vuln(func = "evaluator::select_loss_opportunities", params = list(tc = tc, diff = diff))
   expect_is(dat, "list")
   # ensure that the list has the required elements
   expect_equivalent(names(dat), c("type", "samples", "details"))
@@ -81,11 +88,22 @@ test_that("Sample VULN works with TC and DIFF", {
   # ensure that mean_diff_exceedance is set correctly
   expect_equivalent(floor(dat$details$mean_diff_exceedance), 8)
 })
+test_that("TC and DIFF exceedance handles NA threat events", {
+  set.seed(1234)
+  tc <- c(NA)
+  diff <- sample_diff(params = list(n=2, 50, 70, 85, 2))$samples
+  dat <- sample_vuln(func = "evaluator::select_loss_opportunities", params = list(tc = tc, diff = diff))
+  expect_is(dat, "list")
+  # ensure that mean_tc_exceedance is set correctly
+  expect_equivalent(dat$details$mean_tc_exceedance, NA)
+  # ensure that mean_diff_exceedance is set correctly
+  expect_equivalent(dat$details$mean_diff_exceedance, NA)
+})
 
 context("Sample LM")
 test_that("Sample LM", {
   set.seed(1234)
-  lm <- sample_lm(params = list(10, 1*10^4, 5*10^4, 1*10^7, 3))
+  lm <- sample_lm(params = list(n=10, min=1*10^4, mode=5*10^4, max=1*10^7, shape=3))
   expect_is(lm, "list")
   # ensure that the list has the required elements
   expect_equal(names(lm), c("type", "samples", "details"))
@@ -98,13 +116,27 @@ test_that("Sample LM", {
                         966756.805719722, 941718.366417413, 569057.598433507,
                         1069488.76293628), digits = 4))
 })
+test_that("Non-standard distributions work as expected", {
+  set.seed(1234)
+  lm <- sample_lm(func = "EnvStats::rlnormTrunc", list(n = 10, meanlog = 1, sdlog = 2, min = 1, max = 2))
+  expect_is(lm, "list")
+  # ensure that the list has the required elements
+  expect_equal(names(lm), c("type", "samples", "details"))
+  # ensure that the samples matches the number requested
+  expect_equal(length(lm$samples), 10)
+  # ensure that values of samples is correct
+  expect_equal(signif(unlist(lm$samples), digits = 4),
+               signif(c(1.087017, 1.552746, 1.539039, 1.553887, 1.823434,
+                        1.571874, 1.007058, 1.184094, 1.599599, 1.442124),
+                      digits = 4))
+})
 
 context("Sample LEF")
 test_that("Sample LEF works with composition function", {
   set.seed(1234)
-  tef <- sample_tef(params = list(10, 1, 10, 20))
-  vuln <- sample_vuln(params = list(10, 1, .6))
-  dat <- sample_lef(func = compare_tef_vuln,
+  tef <- sample_tef(params = list(n=10, 1, 10, 20))
+  vuln <- sample_vuln(params = list(n=10, 1, .6))
+  dat <- sample_lef(func = "evaluator::compare_tef_vuln",
              params = list(tef = tef$samples, vuln = vuln$samples))
   expect_is(dat, "list")
   # ensure that the list has the required elements
@@ -119,11 +151,12 @@ test_that("Sample LEF works with composition function", {
 
 context("Standard simulation model")
 test_that("Default simulation model returns expected results", {
-  sim <- openfair_tef_tc_diff_lm(list(tef_l = 1, tef_ml=10, tef_h=100, tef_conf=4,
-                            tc_l = 1, tc_ml = 10, tc_h =75, tc_conf=100,
-                            lm_l=1, lm_ml=100, lm_h = 10000, lm_conf=54),
-                       diff_estimates = data_frame(l=1, ml=10, h = 50, conf =4),
-                       n = 100)
+  sim <- openfair_tef_tc_diff_lm(list(
+    tef_params=list(list(func = "mc2d::rpert", min = 1, mode = 10, max=100, shape=4)),
+    tc_params=list(list(func = "mc2d::rpert", min = 1, mode = 10, max =75, shape=100)),
+    lm_params=list(list(func = "mc2d::rpert", min = 1, mode = 100, max = 10000, shape=54)),
+    diff_params=list(list(list(func = "mc2d::rpert", min = 1, mode = 10, max = 50, shape = 4)))),
+    n = 100)
   expect_s3_class(sim, "tbl_df")
   expect_equal(nrow(sim), 100)
   expect_equal(length(sim), 12)
@@ -133,30 +166,25 @@ test_that("Default simulation model returns expected results", {
 
 context("Main simulation")
 test_that("Full wrapped scenario works as expected", {
-  scenario <- structure(list(scenario_id = 1L, scenario = "Inadequate human resources are available to execute the informaton security strategic security plan.",
-                             tcomm = "Organizational Leadership", domain_id = "ORG", controls = "1, 5, 7, 32, 14, 15, 16",
-                             diff_params = list(structure(list(control_id = c("1", "5",
-                                                                              "7", "32", "14", "15", "16"), label = c("5 - Optimized",
-                                                                                                                      "4 - Managed", "1 - Initial", "4 - Managed", "4 - Managed",
-                                                                                                                      "2 - Repeatable", "2 - Repeatable"), type = c("diff", "diff",
-                                                                                                                                                                    "diff", "diff", "diff", "diff", "diff"), l = c(70L, 50L,
-                                                                                                                                                                                                                   0L, 50L, 50L, 20L, 20L), ml = c(85, 70, 10, 70, 70, 30, 30
-                                                                                                                                                                                                                   ), h = c(98L, 84L, 30L, 84L, 84L, 50L, 50L), conf = c(4L,
-                                                                                                                                                                                                                                                                         4L, 4L, 4L, 4L, 4L, 4L)), class = c("tbl_df", "tbl", "data.frame"
-                                                                                                                                                                                                                                                                         ), row.names = c(NA, -7L), .Names = c("control_id", "label",
-                                                                                                                                                                                                                                                                                                               "type", "l", "ml", "h", "conf"))), tef_l = 10L, tef_ml = 24,
-                             tef_h = 52L, tef_conf = 4L, tc_l = 33L, tc_ml = 50, tc_h = 60L,
-                             tc_conf = 3L, lm_l = 10000L, lm_ml = 20000, lm_h = 500000L,
-                             lm_conf = 4L), .Names = c("scenario_id", "scenario", "tcomm",
-                                                       "domain_id", "controls", "diff_params", "tef_l", "tef_ml", "tef_h",
-                                                       "tef_conf", "tc_l", "tc_ml", "tc_h", "tc_conf", "lm_l", "lm_ml",
-                                                       "lm_h", "lm_conf"), row.names = c(NA, -1L), class = c("tbl_df",
-                                                                                                             "tbl", "data.frame"))
-
+  scenario <-structure(list(scenario_id = "1", scenario = "Inadequate human resources are available to execute the informaton security strategic security plan.",
+                            tcomm = "Organizational Leadership", domain_id = "ORG",
+                            controls = "1, 5, 7, 32, 14, 15, 16",
+                            diff_params = list(list(list(func = "mc2d::rpert", min = 70L, mode = 85L, max = 98L, shape = 4L),
+                                                    list(func = "mc2d::rpert", min = 50L, mode = 70L, max = 84L, shape = 4L),
+                                                    list(func = "mc2d::rpert", min = 0L,  mode = 10L, max = 30L, shape = 4L),
+                                                    list(func = "mc2d::rpert", min = 50L, mode = 70L, max = 84L, shape = 4L),
+                                                    list(func = "mc2d::rpert", min = 20L, mode = 30L, max = 50L, shape = 4L),
+                                                    list(func = "mc2d::rpert", min = 20L, mode = 30L, max = 50L, shape = 4L),
+                                                    list(func = "mc2d::rpert", min = 50L, mode = 70L, max = 84L, shape = 4L))),
+                            tef_params = list(list(func = "mc2d::rpert",min  = 10L, mode = 24, max = 52L, shape = 4L)),
+                            tc_params = list(list(func = "mc2d::rpert", min = 33L, mode = 50, max = 60L, shape = 3L)),
+                            lm_params = list(list(func = "mc2d::rpert", min = 10000L, mode = 20000, max = 500000L, shape = 4L))), row.names = c(NA, -1L),
+                       class = c("tbl_df", "tbl", "data.frame"))
   results <- evaluate_promise(run_simulations(scenario, 100L))
   expect_s3_class(results$result, "tbl_df")
   expect_equal(nrow(results$result), 100)
   expect_equal(length(results$result), 13)
   expect_equal(sum(results$result$threat_events), 2686)
-  expect_equal(sum(results$result$loss_events), 764)
+  #$expect_equal(sum(results$result$loss_events), 764)
+  expect_equal(sum(results$result$loss_events), 772)
 })
